import { program, Command } from '../program.ts';
import { fileIsExist } from '../utils/file.ts';
import path from 'path';
import fs from 'fs';
import { Chalk } from 'chalk';
const chalk = new Chalk({ level: 3 });

const createDevDependencies = (newJson: any) => {
  let change = false;
  if (newJson.devDependencies) {
    change = true;
    newJson.devDependencies = {
      ...newJson.devDependencies,
      '@rollup/plugin-alias': '^5.1.1',
      '@rollup/plugin-commonjs': '^28.0.1',
      '@rollup/plugin-json': '^6.1.0',
      '@rollup/plugin-node-resolve': '^15.3.0',
      '@rollup/plugin-replace': '^6.0.1',
      '@rollup/plugin-typescript': '^12.1.1',
      '@types/node': '^22.9.0',
      chalk: '^5.3.0',
      commander: '^12.1.0',
      glob: '^11.0.0',
      rollup: '^4.26.0',
      'rollup-plugin-copy': '^3.5.0',
      'rollup-plugin-dts': '^6.1.1',
      'rollup-plugin-esbuild': '^6.1.1',
      'rollup-plugin-inject': '^3.0.2',
      tslib: '^2.8.1',
      typescript: '^5.6.2',
    };
  }
  return { json: newJson, change };
};
const command = new Command('init').description('Create a new package or update package').action(async () => {
  const runPath = process.cwd();
  const packageJsonPath = path.resolve(runPath, 'package.json');
  if (fileIsExist(packageJsonPath)) {
    const json = fs.readFileSync(packageJsonPath, 'utf-8');
    try {
      const newJson = JSON.parse(json);
      const { json: _json, change } = createDevDependencies(newJson);
      if (change) {
        fs.writeFileSync(packageJsonPath, JSON.stringify(_json, null, 2));
        console.log(chalk.green('package.json updated'));
      }
    } catch (e) {
      console.log(chalk.red('package.json is invalid'));
    }
  } else {
    const newJson = {
      name: 'new-package',
      version: '1.0.0',
      main: 'dist/index.js',
      module: 'dist/index.mjs',
      types: 'dist/index.d.ts',
      scripts: {
        build: 'rollup -c',
        watch: 'rollup -c w',
      },
      devDependencies: {},
    };
    const { json, change } = createDevDependencies(newJson);
    fs.writeFileSync(packageJsonPath, JSON.stringify(json, null, 2));
    console.log(chalk.green('package.json created'));
  }
});
program.addCommand(command);
